#ifndef NT2_INCLUDE_CONSTANTS_EIGHT_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_EIGHT_HPP_INCLUDED

#include <nt2/constant/include/constants/eight.hpp>

#endif
